@@ -4,6 +4,7 @@ from itertools import combinations
 import math
 import psutil
 
+
 class CombinationDataset(Dataset):
     def __init__(self, dataset):
         self.dataset = dataset
@@ -32,7 +33,7 @@ class ImageFolderWithPaths(datasets.ImageFolder):
         # the image file path
         path = self.imgs[index][0]
         # make a new tuple that includes original and the path
-        tuple_with_path = (original_tuple + (path,))
+        tuple_with_path = original_tuple + (path,)
         return tuple_with_path
 
 
@@ -49,15 +50,17 @@ class FeatureTensorDatasetWithImgName(Dataset):
     def __len__(self):
         return len(self.imgnames)
 
+
 class PermutationIndexDataset(Dataset):
     def __init__(self, datalen):
         self.datalen = datalen
-    
+
     def __getitem__(self, index):
         idx1 = int(math.floor(index / self.datalen))
         idx2 = index % self.datalen
         return idx1, idx2
 
+
 class OriginalandPostProcessedPairsDataset(Dataset):
     def __init__(self, original_feat_dataset, postprocessed_feat_dataset):
         self.original = original_feat_dataset
@@ -72,14 +75,15 @@ class OriginalandPostProcessedPairsDataset(Dataset):
         return (idx1, s1), (idx2, s2)
 
     def __len__(self):
-        return len(self.original)**2
+        return len(self.original) ** 2
+
 
 class PermutationPairsDataset(Dataset):
     def __init__(self, original_feat_dataset, postprocessed=None):
         self.original = original_feat_dataset
         self.datalen = len(self.original)
         self.postprocessed = postprocessed
-    
+
     def __getitem__(self, index):
         idx1 = int(math.floor(index / self.datalen))
         idx2 = index % self.datalen
@@ -89,9 +93,10 @@ class PermutationPairsDataset(Dataset):
         else:
             s2 = self.original[idx2]
         return (idx1, s1), (idx2, s2)
-    
+
     def __len__(self):
-        return len(self.original)**2
+        return len(self.original) ** 2
+
 
 class HDFDataset(Dataset):
     def __init__(self, hdfstore, mem_usage=0.85):
@@ -100,11 +105,13 @@ class HDFDataset(Dataset):
         self.pull_data_to_cache(mem_usage)
         if not self.all_in_cache:
             print("initializing placeholder cache list")
-            self.cache_length = int(psutil.virtual_memory().available*0.85/self.hdfstore[0].nbytes)
-            self.in_cache_idx = [None]*self.cache_length
-            self.in_cache = [None]*self.cache_length
+            self.cache_length = int(
+                psutil.virtual_memory().available * 0.85 / self.hdfstore[0].nbytes
+            )
+            self.in_cache_idx = [None] * self.cache_length
+            self.in_cache = [None] * self.cache_length
             self.cache_counter = 0
-    
+
     def __getitem__(self, index):
         if not self.all_in_cache:
             if index in self.in_cache_idx:
@@ -123,7 +130,10 @@ class HDFDataset(Dataset):
 
     def pull_data_to_cache(self, mem_usage):
         single_row = self.hdfstore[0]
-        if psutil.virtual_memory().available*mem_usage < single_row.nbytes * self.datalen:
+        if (
+            psutil.virtual_memory().available * mem_usage
+            < single_row.nbytes * self.datalen
+        ):
             print("Not enough memory to pull data to cache")
             self.all_in_cache = False
         else:
@@ -131,5 +141,3 @@ class HDFDataset(Dataset):
             self.hdfstore = self.hdfstore[:]
             self.all_in_cache = True
             print("Done pulling data to cache")
-
-
